@@ -53,7 +53,7 @@ void bearing_fill_hbox(GtkWidget *hbox,
     gtk_box_pack_start(GTK_BOX(hbox), gtk_image_new_from_pixbuf(
 			       		icon_bearing(refpos, pos)),1,0,0);
 
-    if(refpos.lat && refpos.lon) {
+    if(!isnan(refpos.lat) && !isnan(refpos.lon)) {
       gtk_box_pack_start_defaults(GTK_BOX(hbox), 
 		   GTK_LABEL_SMALL((char*)pos_get_bearing_str(refpos, pos)));
       snprintf(str, sizeof(str), _("%.1f°"), 
@@ -684,7 +684,7 @@ void cache_dialog(appdata_t *appdata, cache_t *cache) {
   g_object_set_data(G_OBJECT(window), "cur_view", appdata->cur_view);
 
   appdata->cur_cache = cache;
-  char *title = g_strdup_printf("GPXView - %s", cache->name);
+  char *title = g_strdup_printf("%s - GPXView", cache->name);
   gtk_window_set_title(GTK_WINDOW(window), title);
   g_free(title);
 
