@@ -1346,7 +1346,7 @@ float gpx_pos_get_distance(pos_t p1, pos_t p2, int miles) {
 
 void gpx_pos_get_distance_str(char *str, int len, 
 			      pos_t p1, pos_t p2, int mil) {
-  if(!p1.lat && !p1.lon) {
+  if(isnan(p1.lat) || isnan(p1.lon)) {
     snprintf(str, len, "---");
     return;
   }
