@@ -210,7 +210,7 @@ GtkWidget *icon_get_widget(int type, int num) {
 }
 
 GdkPixbuf *icon_bearing(pos_t from, pos_t to) {
-  if(!from.lat && !from.lon)
+  if(isnan(from.lat) && isnan(from.lon))
     return icon_get(ICON_HEADING, 8);
 
   int idx = (gpx_pos_get_bearing(from, to)+22.5)/45.0;
